@@ -1,6 +1,7 @@
 """Roborock API."""
 
-from roborock.api import RoborockClient, RoborockMqttClient
+from roborock.api import RoborockApiClient
+from roborock.cloud_api import RoborockMqttClient
 from roborock.containers import *
 from roborock.exceptions import *
 from roborock.typing import *
